Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1189)

Unified Diff: media/filters/decrypting_video_decoder_unittest.cc

Issue 11492003: Encrypted Media: Support Audio Decrypt-Only. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: comments mostly resolved (I believe); need to add/update tests if this looks good Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/filters/decrypting_video_decoder_unittest.cc
diff --git a/media/filters/decrypting_video_decoder_unittest.cc b/media/filters/decrypting_video_decoder_unittest.cc
index 300763784b42b44b5087b5ea8c608d3a048d53cf..7b3d384e266a7bebfa19a7e9d0c4650e5cd1b4f4 100644
--- a/media/filters/decrypting_video_decoder_unittest.cc
+++ b/media/filters/decrypting_video_decoder_unittest.cc
@@ -230,7 +230,7 @@ class DecryptingVideoDecoderTest : public testing::Test {
}
MOCK_METHOD1(RequestDecryptorNotification,
- void(const DecryptingVideoDecoder::DecryptorNotificationCB&));
+ void(const DecryptingVideoDecoder::DecryptorReadyCB&));
MOCK_METHOD2(FrameReady, void(VideoDecoder::Status,
const scoped_refptr<VideoFrame>&));
@@ -446,21 +446,21 @@ TEST_F(DecryptingVideoDecoderTest, Stop_DuringDecryptorRequested) {
NULL, 0, true, true);
EXPECT_CALL(*demuxer_, video_decoder_config())
.WillRepeatedly(ReturnRef(config_));
- DecryptingVideoDecoder::DecryptorNotificationCB decryptor_notification_cb;
+ DecryptingVideoDecoder::DecryptorReadyCB decryptor_ready_cb;
EXPECT_CALL(*this, RequestDecryptorNotification(_))
- .WillOnce(SaveArg<0>(&decryptor_notification_cb));
+ .WillOnce(SaveArg<0>(&decryptor_ready_cb));
decoder_->Initialize(demuxer_,
NewExpectedStatusCB(DECODER_ERROR_NOT_SUPPORTED),
base::Bind(&MockStatisticsCB::OnStatistics,
base::Unretained(&statistics_cb_)));
message_loop_.RunUntilIdle();
- // |decryptor_notification_cb| is saved but not called here.
- EXPECT_FALSE(decryptor_notification_cb.is_null());
+ // |decryptor_ready_cb| is saved but not called here.
+ EXPECT_FALSE(decryptor_ready_cb.is_null());
// During stop, RequestDecryptorNotification() should be called with a NULL
// callback to cancel the |decryptor_notification_cb|.
EXPECT_CALL(*this, RequestDecryptorNotification(IsNullCallback()))
- .WillOnce(ResetAndRunCallback(&decryptor_notification_cb,
+ .WillOnce(ResetAndRunCallback(&decryptor_ready_cb,
reinterpret_cast<Decryptor*>(NULL)));
Stop();
}
@@ -446,21 +446,21 @@ TEST_F(DecryptingVideoDecoderTest, Stop_DuringDecryptorRequested) {
// During stop, RequestDecryptorNotification() should be called with a NULL
- // callback to cancel the |decryptor_notification_cb|.
+ // callback to cancel the |decryptor_ready_cb|.
EXPECT_CALL(*this, RequestDecryptorNotification(IsNullCallback()))

Powered by Google App Engine
This is Rietveld 408576698